@@ -1,6 +1,3 @@
-#include <string.h>
-#include <stdlib.h>
-
 #include "base.h"
 #include "buffer.h"
 #include "array.h"
@@ -9,6 +6,9 @@
 
 #include "configfile.h"
 
+#include <string.h>
+#include <stdlib.h>
+
 /**
  * like all glue code this file contains functions which
  * are the external interface of lighttpd. The functions
@@ -103,7 +103,6 @@ int config_insert_values_internal(server *srv, array *ca, const config_values_t
 					if (e != ds->value->ptr && !*e && l >=0 && l <= 65535) {
 						*((unsigned short *)(cv[i].destination)) = l;
 						break;
-
 					}
 				}
 
@@ -112,7 +111,37 @@ int config_insert_values_internal(server *srv, array *ca, const config_values_t
 				return -1;
 			}
 			default:
-				log_error_write(srv, __FILE__, __LINE__, "ssds", "unexpected type for key:", cv[i].key, du->type, "expected a integer, range 0 ... 65535");
+				log_error_write(srv, __FILE__, __LINE__, "ssds", "unexpected type for key:", cv[i].key, du->type, "expected a short integer, range 0 ... 65535");
+				return -1;
+			}
+			break;
+		case T_CONFIG_INT:
+			switch(du->type) {
+			case TYPE_INTEGER: {
+				data_integer *di = (data_integer *)du;
+
+				*((unsigned int *)(cv[i].destination)) = di->value;
+				break;
+			}
+			case TYPE_STRING: {
+				data_string *ds = (data_string *)du;
+
+				if (ds->value->ptr && *ds->value->ptr) {
+					char *e;
+					long l = strtol(ds->value->ptr, &e, 10);
+					if (e != ds->value->ptr && !*e && l >= 0) {
+						*((unsigned int *)(cv[i].destination)) = l;
+						break;
+					}
+				}
+
+
+				log_error_write(srv, __FILE__, __LINE__, "ssb", "got a string but expected an integer:", cv[i].key, ds->value);
+
+				return -1;
+			}
+			default:
+				log_error_write(srv, __FILE__, __LINE__, "ssds", "unexpected type for key:", cv[i].key, du->type, "expected an integer, range 0 ... 4294967295");
 				return -1;
 			}
 			break;
@@ -270,17 +299,13 @@ static cond_result_t config_check_cond_nocache(server *srv, connection *con, dat
 				ck_colon = strchr(dc->string->ptr, ':');
 				val_colon = strchr(l->ptr, ':');
 
-				if (ck_colon == val_colon) {
-					/* nothing to do with it */
-					break;
-				}
-				if (ck_colon) {
+				if (NULL != ck_colon && NULL == val_colon) {
 					/* condition "host:port" but client send "host" */
 					buffer_copy_string_buffer(srv->cond_check_buf, l);
 					buffer_append_string_len(srv->cond_check_buf, CONST_STR_LEN(":"));
 					buffer_append_long(srv->cond_check_buf, sock_addr_get_port(&(srv_sock->addr)));
 					l = srv->cond_check_buf;
-				} else if (!ck_colon) {
+				} else if (NULL != val_colon && NULL == ck_colon) {
 					/* condition "host" but client send "host:port" */
 					buffer_copy_string_len(srv->cond_check_buf, l->ptr, val_colon - l->ptr);
 					l = srv->cond_check_buf;
@@ -289,6 +314,10 @@ static cond_result_t config_check_cond_nocache(server *srv, connection *con, dat
 			default:
 				break;
 			}
+#if defined USE_OPENSSL && ! defined OPENSSL_NO_TLSEXT
+		} else if (!buffer_is_empty(con->tlsext_server_name)) {
+			l = con->tlsext_server_name;
+#endif
 		} else {
 			l = srv->empty_string;
 		}
